Class: PlainRouter::OpenAPI::DeleteUserDataRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PlainRouter::OpenAPI::DeleteUserDataRequest
- Defined in:
- lib/plainrouter/openapi/models/delete_user_data_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#identifier_hash ⇒ Object
Returns the value of attribute identifier_hash.
-
#identifier_type ⇒ Object
Returns the value of attribute identifier_type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeleteUserDataRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DeleteUserDataRequest
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/plainrouter/openapi/models/delete_user_data_request.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PlainRouter::OpenAPI::DeleteUserDataRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PlainRouter::OpenAPI::DeleteUserDataRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'identifier_type') self.identifier_type = attributes[:'identifier_type'] else self.identifier_type = nil end if attributes.key?(:'identifier_hash') self.identifier_hash = attributes[:'identifier_hash'] else self.identifier_hash = nil end end |
Instance Attribute Details
#identifier_hash ⇒ Object
Returns the value of attribute identifier_hash.
20 21 22 |
# File 'lib/plainrouter/openapi/models/delete_user_data_request.rb', line 20 def identifier_hash @identifier_hash end |
#identifier_type ⇒ Object
Returns the value of attribute identifier_type.
18 19 20 |
# File 'lib/plainrouter/openapi/models/delete_user_data_request.rb', line 18 def identifier_type @identifier_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/plainrouter/openapi/models/delete_user_data_request.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/plainrouter/openapi/models/delete_user_data_request.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 |
# File 'lib/plainrouter/openapi/models/delete_user_data_request.rb', line 45 def self.attribute_map { :'identifier_type' => :'identifier_type', :'identifier_hash' => :'identifier_hash' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/plainrouter/openapi/models/delete_user_data_request.rb', line 187 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/plainrouter/openapi/models/delete_user_data_request.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 |
# File 'lib/plainrouter/openapi/models/delete_user_data_request.rb', line 63 def self.openapi_types { :'identifier_type' => :'String', :'identifier_hash' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
165 166 167 168 169 170 |
# File 'lib/plainrouter/openapi/models/delete_user_data_request.rb', line 165 def ==(o) return true if self.equal?(o) self.class == o.class && identifier_type == o.identifier_type && identifier_hash == o.identifier_hash end |
#eql?(o) ⇒ Boolean
174 175 176 |
# File 'lib/plainrouter/openapi/models/delete_user_data_request.rb', line 174 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
180 181 182 |
# File 'lib/plainrouter/openapi/models/delete_user_data_request.rb', line 180 def hash [identifier_type, identifier_hash].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/plainrouter/openapi/models/delete_user_data_request.rb', line 107 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @identifier_type.nil? invalid_properties.push('invalid value for "identifier_type", identifier_type cannot be nil.') end if @identifier_hash.nil? invalid_properties.push('invalid value for "identifier_hash", identifier_hash cannot be nil.') end pattern = Regexp.new(/^[a-fA-F0-9]{64}$/) if @identifier_hash !~ pattern invalid_properties.push("invalid value for \"identifier_hash\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/plainrouter/openapi/models/delete_user_data_request.rb', line 209 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
128 129 130 131 132 133 134 135 136 |
# File 'lib/plainrouter/openapi/models/delete_user_data_request.rb', line 128 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @identifier_type.nil? identifier_type_validator = EnumAttributeValidator.new('String', ["email", "phone", "external_id"]) return false unless identifier_type_validator.valid?(@identifier_type) return false if @identifier_hash.nil? return false if @identifier_hash !~ Regexp.new(/^[a-fA-F0-9]{64}$/) true end |