Class: PlainRouter::OpenAPI::EmqSnapshot

Inherits:
ApiModelBase show all
Defined in:
lib/plainrouter/openapi/models/emq_snapshot.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EmqSnapshot

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PlainRouter::OpenAPI::EmqSnapshot` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PlainRouter::OpenAPI::EmqSnapshot`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'signal_tracker_id')
    self.signal_tracker_id = attributes[:'signal_tracker_id']
  else
    self.signal_tracker_id = nil
  end

  if attributes.key?(:'destination_id')
    self.destination_id = attributes[:'destination_id']
  else
    self.destination_id = nil
  end

  if attributes.key?(:'score')
    self.score = attributes[:'score']
  else
    self.score = nil
  end

  if attributes.key?(:'week_over_week_change')
    self.week_over_week_change = attributes[:'week_over_week_change']
  else
    self.week_over_week_change = nil
  end

  if attributes.key?(:'alerted')
    self.alerted = attributes[:'alerted']
  else
    self.alerted = nil
  end

  if attributes.key?(:'platform_response')
    if (value = attributes[:'platform_response']).is_a?(Array)
      self.platform_response = value
    end
  else
    self.platform_response = nil
  end

  if attributes.key?(:'measured_at')
    self.measured_at = attributes[:'measured_at']
  else
    self.measured_at = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#alertedObject

Returns the value of attribute alerted.



28
29
30
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 28

def alerted
  @alerted
end

#created_atObject

Returns the value of attribute created_at.



34
35
36
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 34

def created_at
  @created_at
end

#destination_idObject

Returns the value of attribute destination_id.



22
23
24
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 22

def destination_id
  @destination_id
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 18

def id
  @id
end

#measured_atObject

Returns the value of attribute measured_at.



32
33
34
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 32

def measured_at
  @measured_at
end

#platform_responseObject

Returns the value of attribute platform_response.



30
31
32
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 30

def platform_response
  @platform_response
end

#scoreObject

Returns the value of attribute score.



24
25
26
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 24

def score
  @score
end

#signal_tracker_idObject

Returns the value of attribute signal_tracker_id.



20
21
22
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 20

def signal_tracker_id
  @signal_tracker_id
end

#updated_atObject

Returns the value of attribute updated_at.



36
37
38
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 36

def updated_at
  @updated_at
end

#week_over_week_changeObject

Returns the value of attribute week_over_week_change.



26
27
28
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 26

def week_over_week_change
  @week_over_week_change
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 39

def self.attribute_map
  {
    :'id' => :'id',
    :'signal_tracker_id' => :'signal_tracker_id',
    :'destination_id' => :'destination_id',
    :'score' => :'score',
    :'week_over_week_change' => :'week_over_week_change',
    :'alerted' => :'alerted',
    :'platform_response' => :'platform_response',
    :'measured_at' => :'measured_at',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 306

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
85
86
87
88
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 81

def self.openapi_nullable
  Set.new([
    :'week_over_week_change',
    :'platform_response',
    :'created_at',
    :'updated_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 65

def self.openapi_types
  {
    :'id' => :'Integer',
    :'signal_tracker_id' => :'String',
    :'destination_id' => :'String',
    :'score' => :'Float',
    :'week_over_week_change' => :'Float',
    :'alerted' => :'Boolean',
    :'platform_response' => :'Array<Object>',
    :'measured_at' => :'Time',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 276

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      signal_tracker_id == o.signal_tracker_id &&
      destination_id == o.destination_id &&
      score == o.score &&
      week_over_week_change == o.week_over_week_change &&
      alerted == o.alerted &&
      platform_response == o.platform_response &&
      measured_at == o.measured_at &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


293
294
295
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 293

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



299
300
301
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 299

def hash
  [id, signal_tracker_id, destination_id, score, week_over_week_change, alerted, platform_response, measured_at, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 171

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @signal_tracker_id.nil?
    invalid_properties.push('invalid value for "signal_tracker_id", signal_tracker_id cannot be nil.')
  end

  if @destination_id.nil?
    invalid_properties.push('invalid value for "destination_id", destination_id cannot be nil.')
  end

  if @score.nil?
    invalid_properties.push('invalid value for "score", score cannot be nil.')
  end

  if @alerted.nil?
    invalid_properties.push('invalid value for "alerted", alerted cannot be nil.')
  end

  if @measured_at.nil?
    invalid_properties.push('invalid value for "measured_at", measured_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 328

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
206
207
208
209
210
211
212
# File 'lib/plainrouter/openapi/models/emq_snapshot.rb', line 203

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @signal_tracker_id.nil?
  return false if @destination_id.nil?
  return false if @score.nil?
  return false if @alerted.nil?
  return false if @measured_at.nil?
  true
end