Class: PlainRouter::OpenAPI::EventApi

Inherits:
Object
  • Object
show all
Defined in:
lib/plainrouter/openapi/api/event_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ EventApi

Returns a new instance of EventApi.



19
20
21
# File 'lib/plainrouter/openapi/api/event_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/plainrouter/openapi/api/event_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_event(create_event_request, opts = {}) ⇒ CreateEvent200Response

Submit a conversion event Accepts a consent-aware server-side conversion event. Supply either event_id in the JSON body or Idempotency-Key in the request headers to make retries idempotent.

Parameters:

  • create_event_request (CreateEventRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    Optional idempotency key. When event_id is omitted, PlainRouter uses this value as event_id. If both are supplied, they must match.

Returns:



28
29
30
31
# File 'lib/plainrouter/openapi/api/event_api.rb', line 28

def create_event(create_event_request, opts = {})
  data, _status_code, _headers = create_event_with_http_info(create_event_request, opts)
  data
end

#create_event_with_http_info(create_event_request, opts = {}) ⇒ Array<(CreateEvent200Response, Integer, Hash)>

Submit a conversion event Accepts a consent-aware server-side conversion event. Supply either event_id in the JSON body or Idempotency-Key in the request headers to make retries idempotent.

Parameters:

  • create_event_request (CreateEventRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    Optional idempotency key. When event_id is omitted, PlainRouter uses this value as event_id. If both are supplied, they must match.

Returns:

  • (Array<(CreateEvent200Response, Integer, Hash)>)

    CreateEvent200Response data, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/plainrouter/openapi/api/event_api.rb', line 39

def create_event_with_http_info(create_event_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EventApi.create_event ...'
  end
  # verify the required parameter 'create_event_request' is set
  if @api_client.config.client_side_validation && create_event_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_event_request' when calling EventApi.create_event"
  end
  # resource path
  local_var_path = '/events'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'Idempotency-Key'] = opts[:'idempotency_key'] if !opts[:'idempotency_key'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_event_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CreateEvent200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['signalTrackerSecret']

  new_options = opts.merge(
    :operation => :"EventApi.create_event",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EventApi#create_event\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_event(event, opts = {}) ⇒ GetEvent200Response

Get an event and delivery trace Returns one retained customer-readable event with lineage and destination delivery state.

Parameters:

  • event (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



98
99
100
101
# File 'lib/plainrouter/openapi/api/event_api.rb', line 98

def get_event(event, opts = {})
  data, _status_code, _headers = get_event_with_http_info(event, opts)
  data
end

#get_event_with_http_info(event, opts = {}) ⇒ Array<(GetEvent200Response, Integer, Hash)>

Get an event and delivery trace Returns one retained customer-readable event with lineage and destination delivery state.

Parameters:

  • event (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GetEvent200Response, Integer, Hash)>)

    GetEvent200Response data, response status code and response headers



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/plainrouter/openapi/api/event_api.rb', line 108

def get_event_with_http_info(event, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EventApi.get_event ...'
  end
  # verify the required parameter 'event' is set
  if @api_client.config.client_side_validation && event.nil?
    fail ArgumentError, "Missing the required parameter 'event' when calling EventApi.get_event"
  end
  # resource path
  local_var_path = '/events/{event}'.sub('{event}', CGI.escape(event.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetEvent200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['signalTrackerSecret']

  new_options = opts.merge(
    :operation => :"EventApi.get_event",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EventApi#get_event\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#verify_signal_ingestion(opts = {}) ⇒ CreateEvent200Response

Verify server-side Signal ingestion Writes one identity-free verification event for onboarding and returns the existing event on retry.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



160
161
162
163
# File 'lib/plainrouter/openapi/api/event_api.rb', line 160

def verify_signal_ingestion(opts = {})
  data, _status_code, _headers = verify_signal_ingestion_with_http_info(opts)
  data
end

#verify_signal_ingestion_with_http_info(opts = {}) ⇒ Array<(CreateEvent200Response, Integer, Hash)>

Verify server-side Signal ingestion Writes one identity-free verification event for onboarding and returns the existing event on retry.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CreateEvent200Response, Integer, Hash)>)

    CreateEvent200Response data, response status code and response headers



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/plainrouter/openapi/api/event_api.rb', line 169

def verify_signal_ingestion_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EventApi.verify_signal_ingestion ...'
  end
  # resource path
  local_var_path = '/verification-events'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CreateEvent200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['signalTrackerSecret']

  new_options = opts.merge(
    :operation => :"EventApi.verify_signal_ingestion",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EventApi#verify_signal_ingestion\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end