Class: PlainRouter::OpenAPI::ListEvents200ResponseEvents

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/plainrouter/openapi/models/list_events200_response_events.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListEvents200ResponseEvents

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PlainRouter::OpenAPI::ListEvents200ResponseEvents` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PlainRouter::OpenAPI::ListEvents200ResponseEvents`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'current_page')
    self.current_page = attributes[:'current_page']
  else
    self.current_page = nil
  end

  if attributes.key?(:'data')
    if (value = attributes[:'data']).is_a?(Array)
      self.data = value
    end
  else
    self.data = nil
  end

  if attributes.key?(:'first_page_url')
    self.first_page_url = attributes[:'first_page_url']
  else
    self.first_page_url = nil
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  else
    self.from = nil
  end

  if attributes.key?(:'last_page')
    self.last_page = attributes[:'last_page']
  else
    self.last_page = nil
  end

  if attributes.key?(:'last_page_url')
    self.last_page_url = attributes[:'last_page_url']
  else
    self.last_page_url = nil
  end

  if attributes.key?(:'links')
    if (value = attributes[:'links']).is_a?(Array)
      self.links = value
    end
  else
    self.links = nil
  end

  if attributes.key?(:'next_page_url')
    self.next_page_url = attributes[:'next_page_url']
  else
    self.next_page_url = nil
  end

  if attributes.key?(:'path')
    self.path = attributes[:'path']
  else
    self.path = nil
  end

  if attributes.key?(:'per_page')
    self.per_page = attributes[:'per_page']
  else
    self.per_page = nil
  end

  if attributes.key?(:'prev_page_url')
    self.prev_page_url = attributes[:'prev_page_url']
  else
    self.prev_page_url = nil
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  else
    self.to = nil
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  else
    self.total = nil
  end
end

Instance Attribute Details

#current_pageObject

Returns the value of attribute current_page.



18
19
20
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 18

def current_page
  @current_page
end

#dataObject

Returns the value of attribute data.



20
21
22
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 20

def data
  @data
end

#first_page_urlObject

Returns the value of attribute first_page_url.



22
23
24
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 22

def first_page_url
  @first_page_url
end

#fromObject

Returns the value of attribute from.



24
25
26
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 24

def from
  @from
end

#last_pageObject

Returns the value of attribute last_page.



26
27
28
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 26

def last_page
  @last_page
end

#last_page_urlObject

Returns the value of attribute last_page_url.



28
29
30
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 28

def last_page_url
  @last_page_url
end

Returns the value of attribute links.



30
31
32
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 30

def links
  @links
end

#next_page_urlObject

Returns the value of attribute next_page_url.



32
33
34
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 32

def next_page_url
  @next_page_url
end

#pathObject

Returns the value of attribute path.



34
35
36
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 34

def path
  @path
end

#per_pageObject

Returns the value of attribute per_page.



36
37
38
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 36

def per_page
  @per_page
end

#prev_page_urlObject

Returns the value of attribute prev_page_url.



38
39
40
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 38

def prev_page_url
  @prev_page_url
end

#toObject

Returns the value of attribute to.



40
41
42
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 40

def to
  @to
end

#totalObject

Returns the value of attribute total.



42
43
44
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 42

def total
  @total
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 45

def self.attribute_map
  {
    :'current_page' => :'current_page',
    :'data' => :'data',
    :'first_page_url' => :'first_page_url',
    :'from' => :'from',
    :'last_page' => :'last_page',
    :'last_page_url' => :'last_page_url',
    :'links' => :'links',
    :'next_page_url' => :'next_page_url',
    :'path' => :'path',
    :'per_page' => :'per_page',
    :'prev_page_url' => :'prev_page_url',
    :'to' => :'to',
    :'total' => :'total'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 344

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
97
98
99
100
101
102
103
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 93

def self.openapi_nullable
  Set.new([
    :'first_page_url',
    :'from',
    :'last_page_url',
    :'next_page_url',
    :'path',
    :'prev_page_url',
    :'to',
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 74

def self.openapi_types
  {
    :'current_page' => :'Integer',
    :'data' => :'Array<GetEvent200ResponseEvent>',
    :'first_page_url' => :'String',
    :'from' => :'Integer',
    :'last_page' => :'Integer',
    :'last_page_url' => :'String',
    :'links' => :'Array<ListEvents200ResponseEventsLinksInner>',
    :'next_page_url' => :'String',
    :'path' => :'String',
    :'per_page' => :'Integer',
    :'prev_page_url' => :'String',
    :'to' => :'Integer',
    :'total' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 311

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      current_page == o.current_page &&
      data == o.data &&
      first_page_url == o.first_page_url &&
      from == o.from &&
      last_page == o.last_page &&
      last_page_url == o.last_page_url &&
      links == o.links &&
      next_page_url == o.next_page_url &&
      path == o.path &&
      per_page == o.per_page &&
      prev_page_url == o.prev_page_url &&
      to == o.to &&
      total == o.total
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


331
332
333
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 331

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



337
338
339
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 337

def hash
  [current_page, data, first_page_url, from, last_page, last_page_url, links, next_page_url, path, per_page, prev_page_url, to, total].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 206

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @current_page.nil?
    invalid_properties.push('invalid value for "current_page", current_page cannot be nil.')
  end

  if @data.nil?
    invalid_properties.push('invalid value for "data", data cannot be nil.')
  end

  if @last_page.nil?
    invalid_properties.push('invalid value for "last_page", last_page cannot be nil.')
  end

  if @links.nil?
    invalid_properties.push('invalid value for "links", links cannot be nil.')
  end

  if @per_page.nil?
    invalid_properties.push('invalid value for "per_page", per_page cannot be nil.')
  end

  if @total.nil?
    invalid_properties.push('invalid value for "total", total cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 366

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



238
239
240
241
242
243
244
245
246
247
# File 'lib/plainrouter/openapi/models/list_events200_response_events.rb', line 238

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @current_page.nil?
  return false if @data.nil?
  return false if @last_page.nil?
  return false if @links.nil?
  return false if @per_page.nil?
  return false if @total.nil?
  true
end