Class: PlainRouter::OpenAPI::OperationsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/plainrouter/openapi/api/operations_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ OperationsApi

Returns a new instance of OperationsApi.



19
20
21
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#delete_user_data(delete_user_data_request, opts = {}) ⇒ DeleteUserData200Response

Delete user data by hashed identifier Idempotently removes retained user data matching one caller-supplied SHA-256 identifier digest.

Parameters:

  • delete_user_data_request (DeleteUserDataRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 27

def delete_user_data(delete_user_data_request, opts = {})
  data, _status_code, _headers = delete_user_data_with_http_info(delete_user_data_request, opts)
  data
end

#delete_user_data_with_http_info(delete_user_data_request, opts = {}) ⇒ Array<(DeleteUserData200Response, Integer, Hash)>

Delete user data by hashed identifier Idempotently removes retained user data matching one caller-supplied SHA-256 identifier digest.

Parameters:

  • delete_user_data_request (DeleteUserDataRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(DeleteUserData200Response, Integer, Hash)>)

    DeleteUserData200Response data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 37

def delete_user_data_with_http_info(delete_user_data_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OperationsApi.delete_user_data ...'
  end
  # verify the required parameter 'delete_user_data_request' is set
  if @api_client.config.client_side_validation && delete_user_data_request.nil?
    fail ArgumentError, "Missing the required parameter 'delete_user_data_request' when calling OperationsApi.delete_user_data"
  end
  # resource path
  local_var_path = '/user-data'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(delete_user_data_request)

  # return_type
  return_type = opts[:debug_return_type] || 'DeleteUserData200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['signalTrackerSecret']

  new_options = opts.merge(
    :operation => :"OperationsApi.delete_user_data",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OperationsApi#delete_user_data\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_emq_report(opts = {}) ⇒ GetEmqReport200Response

Get Event Match Quality history Returns recent Meta Event Match Quality snapshots for the authenticated Signal tracker.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



94
95
96
97
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 94

def get_emq_report(opts = {})
  data, _status_code, _headers = get_emq_report_with_http_info(opts)
  data
end

#get_emq_report_with_http_info(opts = {}) ⇒ Array<(GetEmqReport200Response, Integer, Hash)>

Get Event Match Quality history Returns recent Meta Event Match Quality snapshots for the authenticated Signal tracker.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GetEmqReport200Response, Integer, Hash)>)

    GetEmqReport200Response data, response status code and response headers



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 103

def get_emq_report_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OperationsApi.get_emq_report ...'
  end
  # resource path
  local_var_path = '/reports/emq'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetEmqReport200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['signalTrackerSecret']

  new_options = opts.merge(
    :operation => :"OperationsApi.get_emq_report",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OperationsApi#get_emq_report\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_reconciliation_report(date, opts = {}) ⇒ GetReconciliationReport200Response

Get a reconciliation report Returns stored delivery-versus-platform reconciliation results for one calendar date.

Parameters:

  • date (Date)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



152
153
154
155
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 152

def get_reconciliation_report(date, opts = {})
  data, _status_code, _headers = get_reconciliation_report_with_http_info(date, opts)
  data
end

#get_reconciliation_report_with_http_info(date, opts = {}) ⇒ Array<(GetReconciliationReport200Response, Integer, Hash)>

Get a reconciliation report Returns stored delivery-versus-platform reconciliation results for one calendar date.

Parameters:

  • date (Date)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 162

def get_reconciliation_report_with_http_info(date, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OperationsApi.get_reconciliation_report ...'
  end
  # verify the required parameter 'date' is set
  if @api_client.config.client_side_validation && date.nil?
    fail ArgumentError, "Missing the required parameter 'date' when calling OperationsApi.get_reconciliation_report"
  end
  # resource path
  local_var_path = '/reports/reconciliation'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'date'] = date

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetReconciliationReport200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['signalTrackerSecret']

  new_options = opts.merge(
    :operation => :"OperationsApi.get_reconciliation_report",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OperationsApi#get_reconciliation_report\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_events(opts = {}) ⇒ ListEvents200Response

List recent events Returns retained customer-readable events and aggregate destination-delivery acceptance metrics.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :per_page (Integer)

    Events per page, capped at 100. (default to 25)

Returns:



216
217
218
219
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 216

def list_events(opts = {})
  data, _status_code, _headers = list_events_with_http_info(opts)
  data
end

#list_events_by_cursor(opts = {}) ⇒ ListEventsByCursor200Response

List recent events by cursor Returns retained customer-readable events using stable cursor pagination and aggregate destination-delivery acceptance metrics.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :per_page (Integer)

    Events per cursor page, capped at 100. (default to 25)

  • :cursor (String)

    Opaque cursor returned by a previous response. Omit it on the first request.

Returns:



277
278
279
280
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 277

def list_events_by_cursor(opts = {})
  data, _status_code, _headers = list_events_by_cursor_with_http_info(opts)
  data
end

#list_events_by_cursor_with_http_info(opts = {}) ⇒ Array<(ListEventsByCursor200Response, Integer, Hash)>

List recent events by cursor Returns retained customer-readable events using stable cursor pagination and aggregate destination-delivery acceptance metrics.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :per_page (Integer)

    Events per cursor page, capped at 100. (default to 25)

  • :cursor (String)

    Opaque cursor returned by a previous response. Omit it on the first request.

Returns:



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 288

def list_events_by_cursor_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OperationsApi.list_events_by_cursor ...'
  end
  # resource path
  local_var_path = '/dashboard/events/cursor'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil?
  query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListEventsByCursor200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['signalTrackerSecret']

  new_options = opts.merge(
    :operation => :"OperationsApi.list_events_by_cursor",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OperationsApi#list_events_by_cursor\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_events_with_http_info(opts = {}) ⇒ Array<(ListEvents200Response, Integer, Hash)>

List recent events Returns retained customer-readable events and aggregate destination-delivery acceptance metrics.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :per_page (Integer)

    Events per page, capped at 100. (default to 25)

Returns:

  • (Array<(ListEvents200Response, Integer, Hash)>)

    ListEvents200Response data, response status code and response headers



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 226

def list_events_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OperationsApi.list_events ...'
  end
  # resource path
  local_var_path = '/dashboard/events'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListEvents200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['signalTrackerSecret']

  new_options = opts.merge(
    :operation => :"OperationsApi.list_events",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OperationsApi#list_events\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#replay_deliveries(opts = {}) ⇒ ReplayDeliveries202Response

Replay eligible deliveries Evaluates retained failed deliveries and queues the eligible subset for another delivery attempt.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



339
340
341
342
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 339

def replay_deliveries(opts = {})
  data, _status_code, _headers = replay_deliveries_with_http_info(opts)
  data
end

#replay_deliveries_with_http_info(opts = {}) ⇒ Array<(ReplayDeliveries202Response, Integer, Hash)>

Replay eligible deliveries Evaluates retained failed deliveries and queues the eligible subset for another delivery attempt.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(ReplayDeliveries202Response, Integer, Hash)>)

    ReplayDeliveries202Response data, response status code and response headers



349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 349

def replay_deliveries_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OperationsApi.replay_deliveries ...'
  end
  # resource path
  local_var_path = '/deliveries/replay'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'replay_deliveries_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'ReplayDeliveries202Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['signalTrackerSecret']

  new_options = opts.merge(
    :operation => :"OperationsApi.replay_deliveries",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OperationsApi#replay_deliveries\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#send_test_purchase(destination, opts = {}) ⇒ SendTestPurchase200Response

Send a controlled test purchase Creates an identity-free synthetic purchase and sends it only to the selected destination while test mode is enabled.

Parameters:

  • destination (String)

    The destination ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



404
405
406
407
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 404

def send_test_purchase(destination, opts = {})
  data, _status_code, _headers = send_test_purchase_with_http_info(destination, opts)
  data
end

#send_test_purchase_with_http_info(destination, opts = {}) ⇒ Array<(SendTestPurchase200Response, Integer, Hash)>

Send a controlled test purchase Creates an identity-free synthetic purchase and sends it only to the selected destination while test mode is enabled.

Parameters:

  • destination (String)

    The destination ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(SendTestPurchase200Response, Integer, Hash)>)

    SendTestPurchase200Response data, response status code and response headers



415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 415

def send_test_purchase_with_http_info(destination, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OperationsApi.send_test_purchase ...'
  end
  # verify the required parameter 'destination' is set
  if @api_client.config.client_side_validation && destination.nil?
    fail ArgumentError, "Missing the required parameter 'destination' when calling OperationsApi.send_test_purchase"
  end
  # resource path
  local_var_path = '/destinations/{destination}/test-purchase'.sub('{destination}', CGI.escape(destination.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'send_test_purchase_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'SendTestPurchase200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['signalTrackerSecret']

  new_options = opts.merge(
    :operation => :"OperationsApi.send_test_purchase",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OperationsApi#send_test_purchase\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#set_destination_test_mode(destination, set_destination_test_mode_request, opts = {}) ⇒ SetDestinationTestMode200Response

Configure destination test mode Enables or disables Meta Test Events mode for a destination owned by the authenticated Signal tracker.

Parameters:

  • destination (String)

    The destination ID

  • set_destination_test_mode_request (SetDestinationTestModeRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



474
475
476
477
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 474

def set_destination_test_mode(destination, set_destination_test_mode_request, opts = {})
  data, _status_code, _headers = set_destination_test_mode_with_http_info(destination, set_destination_test_mode_request, opts)
  data
end

#set_destination_test_mode_with_http_info(destination, set_destination_test_mode_request, opts = {}) ⇒ Array<(SetDestinationTestMode200Response, Integer, Hash)>

Configure destination test mode Enables or disables Meta Test Events mode for a destination owned by the authenticated Signal tracker.

Parameters:

  • destination (String)

    The destination ID

  • set_destination_test_mode_request (SetDestinationTestModeRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
# File 'lib/plainrouter/openapi/api/operations_api.rb', line 485

def set_destination_test_mode_with_http_info(destination, set_destination_test_mode_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OperationsApi.set_destination_test_mode ...'
  end
  # verify the required parameter 'destination' is set
  if @api_client.config.client_side_validation && destination.nil?
    fail ArgumentError, "Missing the required parameter 'destination' when calling OperationsApi.set_destination_test_mode"
  end
  # verify the required parameter 'set_destination_test_mode_request' is set
  if @api_client.config.client_side_validation && set_destination_test_mode_request.nil?
    fail ArgumentError, "Missing the required parameter 'set_destination_test_mode_request' when calling OperationsApi.set_destination_test_mode"
  end
  # resource path
  local_var_path = '/destinations/{destination}/test-mode'.sub('{destination}', CGI.escape(destination.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(set_destination_test_mode_request)

  # return_type
  return_type = opts[:debug_return_type] || 'SetDestinationTestMode200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['signalTrackerSecret']

  new_options = opts.merge(
    :operation => :"OperationsApi.set_destination_test_mode",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OperationsApi#set_destination_test_mode\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end