Class: PlainRouter::OpenAPI::SendTestPurchaseRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/plainrouter/openapi/models/send_test_purchase_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SendTestPurchaseRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/plainrouter/openapi/models/send_test_purchase_request.rb', line 63

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PlainRouter::OpenAPI::SendTestPurchaseRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PlainRouter::OpenAPI::SendTestPurchaseRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'order_id')
    self.order_id = attributes[:'order_id']
  end
end

Instance Attribute Details

#currencyObject

Returns the value of attribute currency.



20
21
22
# File 'lib/plainrouter/openapi/models/send_test_purchase_request.rb', line 20

def currency
  @currency
end

#order_idObject

Returns the value of attribute order_id.



22
23
24
# File 'lib/plainrouter/openapi/models/send_test_purchase_request.rb', line 22

def order_id
  @order_id
end

#valueObject

Returns the value of attribute value.



18
19
20
# File 'lib/plainrouter/openapi/models/send_test_purchase_request.rb', line 18

def value
  @value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



34
35
36
# File 'lib/plainrouter/openapi/models/send_test_purchase_request.rb', line 34

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



39
40
41
# File 'lib/plainrouter/openapi/models/send_test_purchase_request.rb', line 39

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
31
# File 'lib/plainrouter/openapi/models/send_test_purchase_request.rb', line 25

def self.attribute_map
  {
    :'value' => :'value',
    :'currency' => :'currency',
    :'order_id' => :'order_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/plainrouter/openapi/models/send_test_purchase_request.rb', line 186

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



53
54
55
56
57
58
59
# File 'lib/plainrouter/openapi/models/send_test_purchase_request.rb', line 53

def self.openapi_nullable
  Set.new([
    :'value',
    :'currency',
    :'order_id'
  ])
end

.openapi_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
# File 'lib/plainrouter/openapi/models/send_test_purchase_request.rb', line 44

def self.openapi_types
  {
    :'value' => :'String',
    :'currency' => :'String',
    :'order_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



163
164
165
166
167
168
169
# File 'lib/plainrouter/openapi/models/send_test_purchase_request.rb', line 163

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      value == o.value &&
      currency == o.currency &&
      order_id == o.order_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


173
174
175
# File 'lib/plainrouter/openapi/models/send_test_purchase_request.rb', line 173

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



179
180
181
# File 'lib/plainrouter/openapi/models/send_test_purchase_request.rb', line 179

def hash
  [value, currency, order_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/plainrouter/openapi/models/send_test_purchase_request.rb', line 92

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^-?\d+(?:\.\d+)?$/)
  if !@value.nil? && @value !~ pattern
    invalid_properties.push("invalid value for \"value\", must conform to the pattern #{pattern}.")
  end

  if !@currency.nil? && @currency.to_s.length > 3
    invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.')
  end

  if !@currency.nil? && @currency.to_s.length < 3
    invalid_properties.push('invalid value for "currency", the character length must be greater than or equal to 3.')
  end

  if !@order_id.nil? && @order_id.to_s.length > 128
    invalid_properties.push('invalid value for "order_id", the character length must be smaller than or equal to 128.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/plainrouter/openapi/models/send_test_purchase_request.rb', line 208

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



117
118
119
120
121
122
123
124
# File 'lib/plainrouter/openapi/models/send_test_purchase_request.rb', line 117

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@value.nil? && @value !~ Regexp.new(/^-?\d+(?:\.\d+)?$/)
  return false if !@currency.nil? && @currency.to_s.length > 3
  return false if !@currency.nil? && @currency.to_s.length < 3
  return false if !@order_id.nil? && @order_id.to_s.length > 128
  true
end