Class: PlainRouter::OpenAPI::SetDestinationTestModeRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/plainrouter/openapi/models/set_destination_test_mode_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SetDestinationTestModeRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/plainrouter/openapi/models/set_destination_test_mode_request.rb', line 57

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PlainRouter::OpenAPI::SetDestinationTestModeRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PlainRouter::OpenAPI::SetDestinationTestModeRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  else
    self.enabled = nil
  end

  if attributes.key?(:'test_event_code')
    self.test_event_code = attributes[:'test_event_code']
  end
end

Instance Attribute Details

#enabledObject

Returns the value of attribute enabled.



18
19
20
# File 'lib/plainrouter/openapi/models/set_destination_test_mode_request.rb', line 18

def enabled
  @enabled
end

#test_event_codeObject

Returns the value of attribute test_event_code.



20
21
22
# File 'lib/plainrouter/openapi/models/set_destination_test_mode_request.rb', line 20

def test_event_code
  @test_event_code
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



31
32
33
# File 'lib/plainrouter/openapi/models/set_destination_test_mode_request.rb', line 31

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



36
37
38
# File 'lib/plainrouter/openapi/models/set_destination_test_mode_request.rb', line 36

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
# File 'lib/plainrouter/openapi/models/set_destination_test_mode_request.rb', line 23

def self.attribute_map
  {
    :'enabled' => :'enabled',
    :'test_event_code' => :'test_event_code'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/plainrouter/openapi/models/set_destination_test_mode_request.rb', line 151

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



49
50
51
52
53
# File 'lib/plainrouter/openapi/models/set_destination_test_mode_request.rb', line 49

def self.openapi_nullable
  Set.new([
    :'test_event_code'
  ])
end

.openapi_typesObject

Attribute type mapping.



41
42
43
44
45
46
# File 'lib/plainrouter/openapi/models/set_destination_test_mode_request.rb', line 41

def self.openapi_types
  {
    :'enabled' => :'Boolean',
    :'test_event_code' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



129
130
131
132
133
134
# File 'lib/plainrouter/openapi/models/set_destination_test_mode_request.rb', line 129

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      enabled == o.enabled &&
      test_event_code == o.test_event_code
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


138
139
140
# File 'lib/plainrouter/openapi/models/set_destination_test_mode_request.rb', line 138

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



144
145
146
# File 'lib/plainrouter/openapi/models/set_destination_test_mode_request.rb', line 144

def hash
  [enabled, test_event_code].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/plainrouter/openapi/models/set_destination_test_mode_request.rb', line 84

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @enabled.nil?
    invalid_properties.push('invalid value for "enabled", enabled cannot be nil.')
  end

  if !@test_event_code.nil? && @test_event_code.to_s.length > 100
    invalid_properties.push('invalid value for "test_event_code", the character length must be smaller than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/plainrouter/openapi/models/set_destination_test_mode_request.rb', line 173

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



100
101
102
103
104
105
# File 'lib/plainrouter/openapi/models/set_destination_test_mode_request.rb', line 100

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @enabled.nil?
  return false if !@test_event_code.nil? && @test_event_code.to_s.length > 100
  true
end