Class: PlainRouter::OpenAPI::Destination
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PlainRouter::OpenAPI::Destination
- Defined in:
- lib/plainrouter/openapi/models/destination.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#config ⇒ Object
Returns the value of attribute config.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#credential_source ⇒ Object
Returns the value of attribute credential_source.
-
#id ⇒ Object
Returns the value of attribute id.
-
#platform_ad_account_id ⇒ Object
Returns the value of attribute platform_ad_account_id.
-
#signal_tracker_id ⇒ Object
Returns the value of attribute signal_tracker_id.
-
#status ⇒ Object
Returns the value of attribute status.
-
#type ⇒ Object
Returns the value of attribute type.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Destination
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Destination
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 109 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PlainRouter::OpenAPI::Destination` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PlainRouter::OpenAPI::Destination`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'signal_tracker_id') self.signal_tracker_id = attributes[:'signal_tracker_id'] else self.signal_tracker_id = nil end if attributes.key?(:'platform_ad_account_id') self.platform_ad_account_id = attributes[:'platform_ad_account_id'] else self.platform_ad_account_id = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'credential_source') self.credential_source = attributes[:'credential_source'] else self.credential_source = nil end if attributes.key?(:'config') if (value = attributes[:'config']).is_a?(Array) self.config = value end else self.config = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#config ⇒ Object
Returns the value of attribute config.
28 29 30 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 28 def config @config end |
#created_at ⇒ Object
Returns the value of attribute created_at.
32 33 34 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 32 def created_at @created_at end |
#credential_source ⇒ Object
Returns the value of attribute credential_source.
26 27 28 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 26 def credential_source @credential_source end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 18 def id @id end |
#platform_ad_account_id ⇒ Object
Returns the value of attribute platform_ad_account_id.
22 23 24 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 22 def platform_ad_account_id @platform_ad_account_id end |
#signal_tracker_id ⇒ Object
Returns the value of attribute signal_tracker_id.
20 21 22 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 20 def signal_tracker_id @signal_tracker_id end |
#status ⇒ Object
Returns the value of attribute status.
30 31 32 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 30 def status @status end |
#type ⇒ Object
Returns the value of attribute type.
24 25 26 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 24 def type @type end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
34 35 36 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 34 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 59 def self.attribute_map { :'id' => :'id', :'signal_tracker_id' => :'signal_tracker_id', :'platform_ad_account_id' => :'platform_ad_account_id', :'type' => :'type', :'credential_source' => :'credential_source', :'config' => :'config', :'status' => :'status', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 316 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 103 104 105 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 99 def self.openapi_nullable Set.new([ :'platform_ad_account_id', :'created_at', :'updated_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 84 def self.openapi_types { :'id' => :'String', :'signal_tracker_id' => :'String', :'platform_ad_account_id' => :'Integer', :'type' => :'DestinationType', :'credential_source' => :'DestinationCredentialSource', :'config' => :'Array<Object>', :'status' => :'DestinationStatus', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 287 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && signal_tracker_id == o.signal_tracker_id && platform_ad_account_id == o.platform_ad_account_id && type == o.type && credential_source == o.credential_source && config == o.config && status == o.status && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
303 304 305 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 303 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
309 310 311 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 309 def hash [id, signal_tracker_id, platform_ad_account_id, type, credential_source, config, status, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 182 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @signal_tracker_id.nil? invalid_properties.push('invalid value for "signal_tracker_id", signal_tracker_id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @credential_source.nil? invalid_properties.push('invalid value for "credential_source", credential_source cannot be nil.') end if @config.nil? invalid_properties.push('invalid value for "config", config cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 338 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
214 215 216 217 218 219 220 221 222 223 |
# File 'lib/plainrouter/openapi/models/destination.rb', line 214 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @signal_tracker_id.nil? return false if @type.nil? return false if @credential_source.nil? return false if @config.nil? return false if @status.nil? true end |