Class: PlainRouter::OpenAPI::GetEvent200ResponseEventDeliveriesInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PlainRouter::OpenAPI::GetEvent200ResponseEventDeliveriesInner
- Defined in:
- lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#attempt_count ⇒ Object
Returns the value of attribute attempt_count.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#destination_id ⇒ Object
Returns the value of attribute destination_id.
-
#event_id ⇒ Object
Returns the value of attribute event_id.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_test ⇒ Object
Returns the value of attribute is_test.
-
#last_error ⇒ Object
Returns the value of attribute last_error.
-
#next_attempt_at ⇒ Object
Returns the value of attribute next_attempt_at.
-
#platform_response ⇒ Object
Returns the value of attribute platform_response.
-
#platform_trace_id ⇒ Object
Returns the value of attribute platform_trace_id.
-
#signal_tracker_id ⇒ Object
Returns the value of attribute signal_tracker_id.
-
#status ⇒ Object
Returns the value of attribute status.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetEvent200ResponseEventDeliveriesInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetEvent200ResponseEventDeliveriesInner
Initializes the object
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 128 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PlainRouter::OpenAPI::GetEvent200ResponseEventDeliveriesInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PlainRouter::OpenAPI::GetEvent200ResponseEventDeliveriesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'signal_tracker_id') self.signal_tracker_id = attributes[:'signal_tracker_id'] else self.signal_tracker_id = nil end if attributes.key?(:'event_id') self.event_id = attributes[:'event_id'] else self.event_id = nil end if attributes.key?(:'destination_id') self.destination_id = attributes[:'destination_id'] else self.destination_id = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'is_test') self.is_test = attributes[:'is_test'] else self.is_test = nil end if attributes.key?(:'attempt_count') self.attempt_count = attributes[:'attempt_count'] else self.attempt_count = nil end if attributes.key?(:'last_error') self.last_error = attributes[:'last_error'] else self.last_error = nil end if attributes.key?(:'platform_response') self.platform_response = attributes[:'platform_response'] else self.platform_response = nil end if attributes.key?(:'platform_trace_id') self.platform_trace_id = attributes[:'platform_trace_id'] else self.platform_trace_id = nil end if attributes.key?(:'next_attempt_at') self.next_attempt_at = attributes[:'next_attempt_at'] else self.next_attempt_at = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#attempt_count ⇒ Object
Returns the value of attribute attempt_count.
30 31 32 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 30 def attempt_count @attempt_count end |
#created_at ⇒ Object
Returns the value of attribute created_at.
40 41 42 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 40 def created_at @created_at end |
#destination_id ⇒ Object
Returns the value of attribute destination_id.
24 25 26 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 24 def destination_id @destination_id end |
#event_id ⇒ Object
Returns the value of attribute event_id.
22 23 24 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 22 def event_id @event_id end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 18 def id @id end |
#is_test ⇒ Object
Returns the value of attribute is_test.
28 29 30 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 28 def is_test @is_test end |
#last_error ⇒ Object
Returns the value of attribute last_error.
32 33 34 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 32 def last_error @last_error end |
#next_attempt_at ⇒ Object
Returns the value of attribute next_attempt_at.
38 39 40 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 38 def next_attempt_at @next_attempt_at end |
#platform_response ⇒ Object
Returns the value of attribute platform_response.
34 35 36 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 34 def platform_response @platform_response end |
#platform_trace_id ⇒ Object
Returns the value of attribute platform_trace_id.
36 37 38 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 36 def platform_trace_id @platform_trace_id end |
#signal_tracker_id ⇒ Object
Returns the value of attribute signal_tracker_id.
20 21 22 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 20 def signal_tracker_id @signal_tracker_id end |
#status ⇒ Object
Returns the value of attribute status.
26 27 28 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 26 def status @status end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
42 43 44 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 42 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
86 87 88 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 86 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
91 92 93 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 91 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 67 def self.attribute_map { :'id' => :'id', :'signal_tracker_id' => :'signal_tracker_id', :'event_id' => :'event_id', :'destination_id' => :'destination_id', :'status' => :'status', :'is_test' => :'is_test', :'attempt_count' => :'attempt_count', :'last_error' => :'last_error', :'platform_response' => :'platform_response', :'platform_trace_id' => :'platform_trace_id', :'next_attempt_at' => :'next_attempt_at', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 376 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
115 116 117 118 119 120 121 122 123 124 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 115 def self.openapi_nullable Set.new([ :'destination_id', :'last_error', :'platform_response', :'platform_trace_id', :'next_attempt_at', :'updated_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 96 def self.openapi_types { :'id' => :'Integer', :'signal_tracker_id' => :'String', :'event_id' => :'String', :'destination_id' => :'String', :'status' => :'DeliveryStatus', :'is_test' => :'Boolean', :'attempt_count' => :'Integer', :'last_error' => :'GetEvent200ResponseEventConsent', :'platform_response' => :'GetEvent200ResponseEventConsent', :'platform_trace_id' => :'String', :'next_attempt_at' => :'String', :'created_at' => :'String', :'updated_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 343 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && signal_tracker_id == o.signal_tracker_id && event_id == o.event_id && destination_id == o.destination_id && status == o.status && is_test == o.is_test && attempt_count == o.attempt_count && last_error == o.last_error && platform_response == o.platform_response && platform_trace_id == o.platform_trace_id && next_attempt_at == o.next_attempt_at && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
363 364 365 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 363 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
369 370 371 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 369 def hash [id, signal_tracker_id, event_id, destination_id, status, is_test, attempt_count, last_error, platform_response, platform_trace_id, next_attempt_at, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 223 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @signal_tracker_id.nil? invalid_properties.push('invalid value for "signal_tracker_id", signal_tracker_id cannot be nil.') end if @event_id.nil? invalid_properties.push('invalid value for "event_id", event_id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @is_test.nil? invalid_properties.push('invalid value for "is_test", is_test cannot be nil.') end if @attempt_count.nil? invalid_properties.push('invalid value for "attempt_count", attempt_count cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
398 399 400 401 402 403 404 405 406 407 408 409 410 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 398 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/plainrouter/openapi/models/get_event200_response_event_deliveries_inner.rb', line 259 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @signal_tracker_id.nil? return false if @event_id.nil? return false if @status.nil? return false if @is_test.nil? return false if @attempt_count.nil? return false if @created_at.nil? true end |